@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -105,13 +105,13 @@ def setHandler():
 
                     if sqlalchemy.connector:
                         conf.dbmsConnector = sqlalchemy
-                except Exception, ex:
+                except Exception as ex:
                     exception = ex
 
             if not dialect or exception:
                 try:
                     conf.dbmsConnector.connect()
-                except Exception, ex:
+                except Exception as ex:
                     if exception:
                         raise exception
                     else:
