@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -54,42 +54,42 @@ def smokeTest():
 
     if not checkIntegrity():
         retVal = False
-    else:
-        for root, _, files in os.walk(paths.SQLMAP_ROOT_PATH):
-            if any(_ in root for _ in ("thirdparty", "extra")):
-                continue
 
-            for filename in files:
-                if os.path.splitext(filename)[1].lower() == ".py" and filename != "__init__.py":
-                    length += 1
+    for root, _, files in os.walk(paths.SQLMAP_ROOT_PATH):
+        if any(_ in root for _ in ("thirdparty", "extra")):
+            continue
 
-        for root, _, files in os.walk(paths.SQLMAP_ROOT_PATH):
-            if any(_ in root for _ in ("thirdparty", "extra")):
-                continue
+        for filename in files:
+            if os.path.splitext(filename)[1].lower() == ".py" and filename != "__init__.py":
+                length += 1
 
-            for filename in files:
-                if os.path.splitext(filename)[1].lower() == ".py" and filename != "__init__.py":
-                    path = os.path.join(root, os.path.splitext(filename)[0])
-                    path = path.replace(paths.SQLMAP_ROOT_PATH, '.')
-                    path = path.replace(os.sep, '.').lstrip('.')
-                    try:
-                        __import__(path)
-                        module = sys.modules[path]
-                    except Exception, msg:
+    for root, _, files in os.walk(paths.SQLMAP_ROOT_PATH):
+        if any(_ in root for _ in ("thirdparty", "extra")):
+            continue
+
+        for filename in files:
+            if os.path.splitext(filename)[1].lower() == ".py" and filename != "__init__.py":
+                path = os.path.join(root, os.path.splitext(filename)[0])
+                path = path.replace(paths.SQLMAP_ROOT_PATH, '.')
+                path = path.replace(os.sep, '.').lstrip('.')
+                try:
+                    __import__(path)
+                    module = sys.modules[path]
+                except Exception as ex:
+                    retVal = False
+                    dataToStdout("\r")
+                    errMsg = "smoke test failed at importing module '%s' (%s):\n%s" % (path, os.path.join(root, filename), ex)
+                    logger.error(errMsg)
+                else:
+                    # Run doc tests
+                    # Reference: http://docs.python.org/library/doctest.html
+                    (failure_count, test_count) = doctest.testmod(module)
+                    if failure_count > 0:
                         retVal = False
-                        dataToStdout("\r")
-                        errMsg = "smoke test failed at importing module '%s' (%s):\n%s" % (path, os.path.join(root, filename), msg)
-                        logger.error(errMsg)
-                    else:
-                        # Run doc tests
-                        # Reference: http://docs.python.org/library/doctest.html
-                        (failure_count, test_count) = doctest.testmod(module)
-                        if failure_count > 0:
-                            retVal = False
 
-                    count += 1
-                    status = '%d/%d (%d%%) ' % (count, length, round(100.0 * count / length))
-                    dataToStdout("\r[%s] [INFO] complete: %s" % (time.strftime("%X"), status))
+                count += 1
+                status = '%d/%d (%d%%) ' % (count, length, round(100.0 * count / length))
+                dataToStdout("\r[%s] [INFO] complete: %s" % (time.strftime("%X"), status))
 
     clearConsoleLine()
     if retVal:
@@ -275,10 +275,10 @@ def runCase(parse):
         result = start()
     except KeyboardInterrupt:
         pass
-    except SqlmapBaseException, e:
-        handled_exception = e
-    except Exception, e:
-        unhandled_exception = e
+    except SqlmapBaseException as ex:
+        handled_exception = ex
+    except Exception as ex:
+        unhandled_exception = ex
     finally:
         sys.stdout.seek(0)
         console = sys.stdout.read()
