@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -29,9 +29,6 @@ class Connector(GenericConnector):
     License: MIT
     """
 
-    def __init__(self):
-        GenericConnector.__init__(self)
-
     def connect(self):
         if not IS_WIN:
             errMsg = "currently, direct connection to Microsoft Access database(s) "
