@@ -1,7 +1,7 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
-Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -12,9 +12,6 @@ from lib.core.common import randomStr
 from plugins.generic.syntax import Syntax as GenericSyntax
 
 class Syntax(GenericSyntax):
-    def __init__(self):
-        GenericSyntax.__init__(self)
-
     @staticmethod
     def escape(expression, quote=True):
         """
@@ -41,4 +38,4 @@ class Syntax(GenericSyntax):
             for _ in excluded.items():
                 retVal = retVal.replace(_[1], _[0])
 
-        return retVal
\ No newline at end of file
+        return retVal
