@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -17,6 +17,7 @@ from lib.core.common import safeStringFormat
 from lib.core.common import singleTimeLogMessage
 from lib.core.common import unArrayizeValue
 from lib.core.common import unsafeSQLIdentificatorNaming
+from lib.core.compat import xrange
 from lib.core.data import conf
 from lib.core.data import kb
 from lib.core.data import logger
@@ -28,13 +29,10 @@ from lib.core.enums import PAYLOAD
 from lib.core.exception import SqlmapNoneDataException
 from lib.core.settings import CURRENT_DB
 from lib.request import inject
-
 from plugins.generic.enumeration import Enumeration as GenericEnumeration
+from thirdparty import six
 
 class Enumeration(GenericEnumeration):
-    def __init__(self):
-        GenericEnumeration.__init__(self)
-
     def getPrivileges(self, *args):
         warnMsg = "on Microsoft SQL Server it is not possible to fetch "
         warnMsg += "database users privileges, sqlmap will check whether "
@@ -83,10 +81,10 @@ class Enumeration(GenericEnumeration):
         for db in dbs:
             dbs[dbs.index(db)] = safeSQLIdentificatorNaming(db)
 
-        dbs = filter(None, dbs)
+        dbs = [_ for _ in dbs if _]
 
         infoMsg = "fetching tables for database"
-        infoMsg += "%s: %s" % ("s" if len(dbs) > 1 else "", ", ".join(db if isinstance(db, basestring) else db[0] for db in sorted(dbs)))
+        infoMsg += "%s: %s" % ("s" if len(dbs) > 1 else "", ", ".join(db if isinstance(db, six.string_types) else db[0] for db in sorted(dbs)))
         logger.info(infoMsg)
 
         rootQuery = queries[DBMS.MSSQL].tables
@@ -110,7 +108,7 @@ class Enumeration(GenericEnumeration):
                         break
 
                 if not isNoneValue(value):
-                    value = filter(None, arrayizeValue(value))
+                    value = [_ for _ in arrayizeValue(value) if _]
                     value = [safeSQLIdentificatorNaming(unArrayizeValue(_), True) for _ in value]
                     kb.data.cachedTables[db] = value
 
@@ -222,7 +220,7 @@ class Enumeration(GenericEnumeration):
                     values = inject.getValue(query, blind=False, time=False)
 
                     if not isNoneValue(values):
-                        if isinstance(values, basestring):
+                        if isinstance(values, six.string_types):
                             values = [values]
 
                         for foundTbl in values:
@@ -340,7 +338,7 @@ class Enumeration(GenericEnumeration):
             colQuery = "%s%s" % (colCond, colCondParam)
             colQuery = colQuery % unsafeSQLIdentificatorNaming(column)
 
-            for db in filter(None, dbs.keys()):
+            for db in (_ for _ in dbs if _):
                 db = safeSQLIdentificatorNaming(db)
 
                 if conf.excludeSysDbs and db in self.excludeDbsList:
@@ -356,7 +354,7 @@ class Enumeration(GenericEnumeration):
                     values = inject.getValue(query, blind=False, time=False)
 
                     if not isNoneValue(values):
-                        if isinstance(values, basestring):
+                        if isinstance(values, six.string_types):
                             values = [values]
 
                         for foundTbl in values:
