@@ -1,7 +1,7 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -23,18 +23,14 @@ class PostgreSQLMap(Syntax, Fingerprint, Enumeration, Filesystem, Miscellaneous,
     def __init__(self):
         self.excludeDbsList = PGSQL_SYSTEM_DBS
         self.sysUdfs = {
-                         # UDF name:     UDF parameters' input data-type and return data-type
-                         "sys_exec":     { "input":  ["text"], "return": "int4" },
-                         "sys_eval":     { "input":  ["text"], "return": "text" },
-                         "sys_bineval":  { "input":  ["text"], "return": "int4" },
-                         "sys_fileread": { "input":  ["text"], "return": "text" }
-                       }
+            # UDF name: UDF parameters' input data-type and return data-type
+            "sys_exec": {"input": ["text"], "return": "int4"},
+            "sys_eval": {"input": ["text"], "return": "text"},
+            "sys_bineval": {"input": ["text"], "return": "int4"},
+            "sys_fileread": {"input": ["text"], "return": "text"}
+        }
 
-        Syntax.__init__(self)
-        Fingerprint.__init__(self)
-        Enumeration.__init__(self)
-        Filesystem.__init__(self)
-        Miscellaneous.__init__(self)
-        Takeover.__init__(self)
+        for cls in self.__class__.__bases__:
+            cls.__init__(self)
 
     unescaper[DBMS.PGSQL] = Syntax.escape
