@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -13,6 +13,7 @@ except:
 
 import logging
 
+from lib.core.common import getSafeExString
 from lib.core.convert import utf8encode
 from lib.core.data import conf
 from lib.core.data import logger
@@ -33,16 +34,13 @@ class Connector(GenericConnector):
     to work, get it from http://sourceforge.net/projects/pymssql/files/pymssql/1.0.2/
     """
 
-    def __init__(self):
-        GenericConnector.__init__(self)
-
     def connect(self):
         self.initConnection()
 
         try:
             self.connector = pymssql.connect(host="%s:%d" % (self.hostname, self.port), user=self.user, password=self.password, database=self.db, login_timeout=conf.timeout, timeout=conf.timeout)
-        except (pymssql.Error, _mssql.MssqlDatabaseException), msg:
-            raise SqlmapConnectionException(msg)
+        except (pymssql.Error, _mssql.MssqlDatabaseException) as ex:
+            raise SqlmapConnectionException(ex)
         except ValueError:
             raise SqlmapConnectionException
 
@@ -52,8 +50,8 @@ class Connector(GenericConnector):
     def fetchall(self):
         try:
             return self.cursor.fetchall()
-        except (pymssql.Error, _mssql.MssqlDatabaseException), msg:
-            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) %s" % str(msg).replace("\n", " "))
+        except (pymssql.Error, _mssql.MssqlDatabaseException) as ex:
+            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) '%s'" % getSafeExString(ex).replace("\n", " "))
             return None
 
     def execute(self, query):
@@ -62,10 +60,10 @@ class Connector(GenericConnector):
         try:
             self.cursor.execute(utf8encode(query))
             retVal = True
-        except (pymssql.OperationalError, pymssql.ProgrammingError), msg:
-            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) %s" % str(msg).replace("\n", " "))
-        except pymssql.InternalError, msg:
-            raise SqlmapConnectionException(msg)
+        except (pymssql.OperationalError, pymssql.ProgrammingError) as ex:
+            logger.log(logging.WARN if conf.dbmsHandler else logging.DEBUG, "(remote) '%s'" % getSafeExString(ex).replace("\n", " "))
+        except pymssql.InternalError as ex:
+            raise SqlmapConnectionException(getSafeExString(ex))
 
         return retVal
 
