@@ -1,7 +1,7 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
-Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -21,6 +21,7 @@ from lib.core.common import isTechniqueAvailable
 from lib.core.common import parsePasswordHash
 from lib.core.common import readInput
 from lib.core.common import unArrayizeValue
+from lib.core.compat import xrange
 from lib.core.convert import hexencode
 from lib.core.data import conf
 from lib.core.data import kb
@@ -171,7 +172,7 @@ class Users:
         else:
             users = []
 
-        users = filter(None, users)
+        users = [_ for _ in users if _]
 
         if any(isTechniqueAvailable(_) for _ in (PAYLOAD.TECHNIQUE.UNION, PAYLOAD.TECHNIQUE.ERROR, PAYLOAD.TECHNIQUE.QUERY)) or conf.direct:
             if Backend.isDbms(DBMS.MSSQL) and Backend.isVersionWithin(("2005", "2008")):
@@ -201,6 +202,9 @@ class Users:
             else:
                 values = inject.getValue(query, blind=False, time=False)
 
+                if isNoneValue(values) and Backend.isDbms(DBMS.MSSQL):
+                    values = inject.getValue(query.replace("master.dbo.fn_varbintohexstr", "sys.fn_sqlvarbasetostr"), blind=False, time=False)
+
                 for user, password in filterPairValues(values):
                     if not user or user == " ":
                         continue
@@ -213,6 +217,8 @@ class Users:
                         kb.data.cachedUsersPasswords[user].append(password)
 
         if not kb.data.cachedUsersPasswords and isInferenceAvailable() and not conf.direct:
+            fallback = False
+
             if not len(users):
                 users = self.getUsers()
 
@@ -263,6 +269,10 @@ class Users:
 
                         count = inject.getValue(query, union=False, error=False, expected=EXPECTED.INT, charsetType=CHARSET_TYPE.DIGITS)
 
+                        if not isNumPosStrValue(count) and Backend.isDbms(DBMS.MSSQL):
+                            fallback = True
+                            count = inject.getValue(query.replace("master.dbo.fn_varbintohexstr", "sys.fn_sqlvarbasetostr"), union=False, error=False, expected=EXPECTED.INT, charsetType=CHARSET_TYPE.DIGITS)
+
                         if not isNumPosStrValue(count):
                             warnMsg = "unable to retrieve the number of password "
                             warnMsg += "hashes for user '%s'" % user
@@ -283,10 +293,16 @@ class Users:
                                 query = rootQuery.blind.query2 % (user, index, user)
                             else:
                                 query = rootQuery.blind.query % (user, index, user)
+
+                            if fallback:
+                                query = query.replace("master.dbo.fn_varbintohexstr", "sys.fn_sqlvarbasetostr")
+
                         elif Backend.isDbms(DBMS.INFORMIX):
                             query = rootQuery.blind.query % (user,)
+
                         elif Backend.isDbms(DBMS.HSQLDB):
                             query = rootQuery.blind.query % (index, user)
+
                         else:
                             query = rootQuery.blind.query % (user, index)
 
@@ -355,7 +371,7 @@ class Users:
         else:
             users = []
 
-        users = filter(None, users)
+        users = [_ for _ in users if _]
 
         # Set containing the list of DBMS administrators
         areAdmins = set()
