@@ -1,12 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
-import re
-
 from lib.core.settings import WAF_ATTACK_VECTORS
 
 __product__ = "360 Web Application Firewall (360)"
@@ -16,8 +14,9 @@ def detect(get_page):
 
     for vector in WAF_ATTACK_VECTORS:
         page, headers, code = get_page(get=vector)
-        retval = re.search(r"wangzhan\.360\.cn", headers.get("X-Powered-By-360wzb", ""), re.I) is not None
+        retval = headers.get("X-Powered-By-360wzb") is not None
         retval |= code == 493 and "/wzws-waf-cgi/" in (page or "")
+        retval |= all(_ in (page or "") for _ in ("eventID", "If you are the Webmaster", "<title>493</title>"))
         if retval:
             break
 
