@@ -1,12 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
-import re
-
 from lib.core.settings import WAF_ATTACK_VECTORS
 
 __product__ = "Varnish FireWall (OWASP)"
@@ -15,9 +13,8 @@ def detect(get_page):
     retval = False
 
     for vector in WAF_ATTACK_VECTORS:
-        page, headers, code = get_page(get=vector)
-        retval = code == 404 and re.search(r"\bXID: \d+", page or "") is not None
-        retval |= code >= 400 and "Request rejected by xVarnish-WAF" in (page or "")
+        page, _, code = get_page(get=vector)
+        retval = code >= 400 and "Request rejected by xVarnish-WAF" in (page or "")
         if retval:
             break
 
